@@ -25,14 +25,14 @@ class SparqlSource(DataSource):
         log.info('Succes!')
 
 
-    def handle(self, ki, binding_set):
+    def handle(self, ki, binding_set, requesting_kb):
         if ki['type'] == 'answer':
-            return self.handle_answer(ki, binding_set)
+            return self.handle_answer(ki, binding_set, requesting_kb)
         elif ki['type'] == 'react':
-            return self.handle_react(ki, binding_set)
+            return self.handle_react(ki, binding_set, requesting_kb)
 
 
-    def handle_answer(self, ki, binding_set):
+    def handle_answer(self, ki, binding_set, requesting_kb):
         # Generate the SPARQL query based on the incoming bindings and the knowledge interaction's graph pattern.
         query = generate_sparql_select(ki, binding_set)
         # Fire the SPARQL query.
@@ -41,7 +41,7 @@ class SparqlSource(DataSource):
         return restructure_bindings(result)
 
 
-    def handle_react(self, ki, binding_set):
+    def handle_react(self, ki, binding_set, requesting_kb):
         # Generate the SPARQL query based on the incoming bindings and the knowledge interaction's graph pattern.
         query = generate_sparql_insert(ki, binding_set)
         # Fire the SPARQL query.
@@ -136,7 +136,14 @@ def generate_sparql_select(ki, incoming_bindings):
 
 def generate_sparql_insert(ki, bindings):
     variables = ki['vars']
+    if 'prefixes' in ki:
+        prefixes = ki['prefixes']
+    else:
+        prefixes = dict()
+    pref = '\n\t'.join(f"PREFIX {prefix}: <{ki['prefixes'][prefix]}>" for prefix in prefixes.keys())
+
     return f'''
+        {pref}
         INSERT {{
             {ki['argument_pattern']}
         }} WHERE {{ VALUES ({' '.join([f'?{variable}' for variable in variables])}) {{
